---
name: Bug report
about: Create a report to help us improve
title: "[BUG] - title of the issue"
labels: bug
assignees: ''

---

# Describe the bug
A clear and concise description of what the bug is. Remember to try to reproduce your bug with the latest version of the _dev_ branch, the problem may already have been solved.

# To Reproduce
Steps to reproduce the behavior:
for example:
1. use function XXX
2. insert this argument
3. See error

**IMPORTANT**
If you failed to convert a specific geometry, please isolate the geometry features producing the bug (ideally a single body), save it as a STEP file and attach it to this issue. Include also all the files used in the conversion as well as the GEOUNED version used.

# Expected behavior
A clear and concise description of what you expected to happen.

# Error message
If applicable, include the error message displayed in the console: strange type of surface, unexpected exit, python
exception…

# Screenshots
If applicable, add screenshots to help explain your problem.

# Please complete the following information):
 - OS: [e.g. Linux or Windows]
 - GEOUNED version
 - Python version

# Additional context
Add any other context about the problem here.